@@ -3,6 +3,4 @@ from .Chat import *
 from .Constants import *
 from .Entities import *
 from .InlineKeyboard import *
-from .Message import *
-from .Update import *
 from .User import *
\ No newline at end of file
